@@ -3,21 +3,18 @@ BEGIN {
   $App::DuckPAN::Cmd::Check::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Command for checking the requirements
-$App::DuckPAN::Cmd::Check::VERSION = '0.162';
+$App::DuckPAN::Cmd::Check::VERSION = '0.163';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
 use MooX::Options protect_argv => 0;
 
 sub run {
-	my ( $self ) = @_;
-	$self->app->verify_versions;
-	if ($self->app->check_requirements) {
-		print "\n[ERROR] Check for the requirements failed!! See instructions or reports above\n\n";
-		exit 1;
-	} else {
-		print "\nEVERYTHING OK! You can now go hacking! :)\n\n";
-	}
+	my ($self) = @_;
+
+	$self->app->check_requirements; # Exits on missing requirements.
+	$self->app->emit_info("EVERYTHING OK! You can now go hacking! :)");
+	exit 0;
 }
 
 1;
@@ -32,7 +29,7 @@ App::DuckPAN::Cmd::Check - Command for checking the requirements
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
