@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Installdeps::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Regular way to install requirements with tests
-$App::DuckPAN::Cmd::Installdeps::VERSION = '0.162';
+$App::DuckPAN::Cmd::Installdeps::VERSION = '0.163';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -13,16 +13,12 @@ sub run {
 	my ( $self, @args ) = @_;
 
 	if (-f 'dist.ini') {
-		$self->app->print_text(
-			"Found a dist.ini, suggesting a Dist::Zilla distribution",
-		);
+		$self->app->emit_info("Found a dist.ini, suggesting a Dist::Zilla distribution");
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil authordeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm"));
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil listdeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm"));
-		$self->app->print_text(
-			"Everything fine!",
-		);
+		$self->app->emit_info("Everything fine!");
 	}
 
 }
@@ -39,7 +35,7 @@ App::DuckPAN::Cmd::Installdeps - Regular way to install requirements with tests
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
