@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::New::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Take a name as input and generates a new, named Goodie or Spice instant answer skeleton
-$App::DuckPAN::Cmd::New::VERSION = '0.162';
+$App::DuckPAN::Cmd::New::VERSION = '0.163';
 # For Goodies:
 # 	- <name>.pm file is created in lib/DDG/Goodie
 #
@@ -27,7 +27,7 @@ sub run {
 
 	# Instant Answer name as parameter
 	my $entered_name = (@args) ? join(' ', @args) : $self->app->get_reply('Please enter a name for your Instant Answer');
-	$self->app->exit_with_msg(-1, "Must supply a name for your Instant Answer.") unless $entered_name;
+	$self->app->emit_and_exit(-1, "Must supply a name for your Instant Answer.") unless $entered_name;
 	$entered_name =~ s/\//::/g;    #change "/" to "::" for easier handling
 	my $name = $self->app->phrase_to_camel($entered_name);
 	my ($package_name, $separated_name, $path, $lc_path) = ($name, $name, "", "");
@@ -40,7 +40,7 @@ sub run {
 			$path    = join("/", @path_parts);
 			$lc_path = join("/", map { $self->app->camel_to_underscore($_) } @path_parts);
 		} else {
-			$self->app->exit_with_msg(-1, "Malformed input. Please provide a properly formatted package name for your Instant Answer.");
+			$self->app->emit_and_exit(-1, "Malformed input. Please provide a properly formatted package name for your Instant Answer.");
 		}
 	}
 
@@ -52,7 +52,7 @@ sub run {
 		$lc_name = $lc_path . "_" . $lc_name;
 	}
 
-	$self->app->exit_with_msg(-1, "No templates exist for this IA Type: " . $type->{name}) if (!defined $type->{templates});
+	$self->app->emit_and_exit(-1, "No templates exist for this IA Type: " . $type->{name}) if (!defined $type->{templates});
 
 	my %template_info = %{$type->{templates}};
 	my $tx            = Text::Xslate->new();
@@ -70,15 +70,15 @@ sub run {
 	);
 	foreach my $template_type (sort keys %template_info) {
 		my ($source, $dest) = ($template_info{$template_type}{in}, $template_info{$template_type}{out});
-		$self->app->exit_with_msg(-1, 'Template does not exist: ' . $source) unless ($source->exists);
+		$self->app->emit_and_exit(-1, 'Template does not exist: ' . $source) unless ($source->exists);
 		# Update dest based on type:
 		$dest = $dest->child(@{$files{$template_type}});
-		$self->app->exit_with_msg(-1, 'File already exists: "' . $dest->basename . '" in ' . $dest->parent) if ($dest->exists);
+		$self->app->emit_and_exit(-1, 'File already exists: "' . $dest->basename . '" in ' . $dest->parent) if ($dest->exists);
 		my $content = $tx->render("$source", \%vars);
 		$dest->touchpath->append_utf8($content);    #create file path and append to file
-		$self->app->print_text("Created file: $dest");
+		$self->app->emit_info("Created file: $dest");
 	}
-	$self->app->print_text("Successfully created " . $type->{name} . ": $package_name");
+	$self->app->emit_info("Successfully created " . $type->{name} . ": $package_name");
 }
 
 1;
@@ -93,7 +93,7 @@ App::DuckPAN::Cmd::New - Take a name as input and generates a new, named Goodie
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
