@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Poupload::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Command for uploading .po files to the DuckDuckGo Community Platform
-$App::DuckPAN::Cmd::Poupload::VERSION = '0.162';
+$App::DuckPAN::Cmd::Poupload::VERSION = '0.163';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -52,12 +52,12 @@ sub run {
 }
 
 sub upload {
-	my ( $self, $file ) = @_;
-	die "File not found" unless -f $file;
-	print "Uploading ".$file."... ";
+	my ($self, $file) = @_;
+	$self->app->emit_and_exit(1, "File not found: " . $file) unless -f $file;
+	$self->app->emit_info("Uploading $file... ");
 	my $response = $self->app->http->request($self->get_request($file));
-	die "Error: ".$response->code if $response->is_error || $response->is_redirect;
-	print "success!\n";
+	$self->app->emit_and_exit(1, "Error: " . $response->code) if $response->is_error || $response->is_redirect;
+	$self->app->emit_info("Upload completed successfully.");
 }
 
 1;
@@ -72,7 +72,7 @@ App::DuckPAN::Cmd::Poupload - Command for uploading .po files to the DuckDuckGo
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
