@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Roadrunner::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Install requirements as fast as possible
-$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.162';
+$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.163';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -14,31 +14,23 @@ sub run {
 	my ( $self, @args ) = @_;
 
 	if (-f 'dist.ini') {
-		$self->app->print_text(
-			"Found a dist.ini, suggesting a Dist::Zilla distribution",
-		);
+		$self->app->emit_info("Found a dist.ini, suggesting a Dist::Zilla distribution");
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil authordeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm --quiet --notest --skip-satisfied"));
 		$self->app->perl->cpanminus_install_error
 			if (system("dzil listdeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm --quiet --notest --skip-satisfied"));
-		$self->app->print_text(
-			"Everything fine!",
-		);
+		$self->app->emit_info("Everything fine!");
 	} elsif (-f 'Makefile.PL') {
-		$self->app->print_text(
-			"Found a Makefile.PL",
-		);
+		$self->app->emit_info("Found a Makefile.PL");
 		$self->app->perl->cpanminus_install_error
 			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
 	} elsif (-f 'Build.PL') {
-		$self->app->print_text(
-			"Found a Build.PL",
-		);
+		$self->app->emit_info("Found a Build.PL");
 		$self->app->perl->cpanminus_install_error
 			if (system("cpanm --quiet --notest --skip-satisfied --installdeps ."));
 	}
 
-	print "\a"; usleep 225000; print "\a";
+	$self->app->emit_info("\a"); usleep 225000; $self->app->emit_info("\a");
 
 }
 
@@ -54,7 +46,7 @@ App::DuckPAN::Cmd::Roadrunner - Install requirements as fast as possible
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
