@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::CmdBase::Env::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Base class for ENV related functionality of duckpan (duckpan env and duckpan rm)
-$App::DuckPAN::CmdBase::Env::VERSION = '0.162';
+$App::DuckPAN::CmdBase::Env::VERSION = '0.163';
 use MooX qw( Options );
 use Path::Tiny;
 use Config::INI;
@@ -56,24 +56,19 @@ sub rm_env {
 sub show_env {
   my ( $self, $name ) = @_;
   if ($self->get_env($name)) {
-    print 'export '.$name.'=\''.$self->get_env($name).'\''."\n";
+    $self->app->emit_info('export '.$name.'=\''.$self->get_env($name).'\'');
   } else {
-    print '# '.$name.' is not set'."\n";
+    $self->app->emit_info('# '.$name.' is not set');
   }
 }
 
 sub show_usage {
-  my ( $self ) = @_;
-  if (keys %{$self->load_env_ini}) {
-    print STDOUT "# ENV variables added so far:\n";
-    $self->show_env($_) for (sort keys %{$self->load_env_ini});
-    print STDOUT "\n";
-  }
-  printf STDERR "Usage:\n";
-  printf STDERR "  %12s\tduckpan env <name> <value>\n", "add ENV:";
-  printf STDERR "  %12s\tduckpan env <name>\n", "get ENV:";
-  printf STDERR "  %12s\tduckpan rm <name>\n", "remove ENV:";
-  exit 1;
+    my ($self) = @_;
+    if (keys %{$self->load_env_ini}) {
+        $self->app->emit_info("# ENV variables added so far:");
+        $self->show_env($_) for (sort keys %{$self->load_env_ini});
+    }
+    $self->app->emit_and_exit(1, "Usage:", "\tset: duckpan env <name> <value>", "get: duckpan env <name>", "\t rm: duckpan rm <name>\n");
 }
 
 1;
@@ -88,7 +83,7 @@ App::DuckPAN::CmdBase::Env - Base class for ENV related functionality of duckpan
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
