@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::DDG::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: DDG related functionality of duckpan
-$App::DuckPAN::DDG::VERSION = '0.162';
+$App::DuckPAN::DDG::VERSION = '0.163';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
@@ -13,37 +13,35 @@ use Data::Printer;
 use List::Util qw (first);
 
 sub get_dukgo_user_pass {
-    my ( $self ) = @_;
+    my ($self) = @_;
     my $config = $self->app->perl->get_dzil_config;
-    unless (defined $config->{'%DUKGO'}) {
-        shift->app->print_text(
-            "[ERROR] No configuration found for your https://duck.co/ username and password, please use: 'dzil setup' first!",
-        );
-        exit 1;
-    }
+    $self->app->emit_and_exit(1, "No configuration found for your https://duck.co/ username and password", "Please use 'dzil setup' first!")
+      unless (defined $config->{'%DUKGO'});
+
     return $config->{'%DUKGO'}->{username}, $config->{'%DUKGO'}->{password};
 }
 
 # This function tells the user which modules / instant answers failed to load.
-sub print_failed_modules {
-    my %failed_to_load = %{shift @_};
+sub show_failed_modules {
+    my ($self, $failed_to_load) = @_;
 
-    # Print out the missing modules in color.
-    if(%failed_to_load) {
-        print "\nThese instant answers were not loaded:\n";
-        p(%failed_to_load);
-        print "To learn more about installing Perl dependencies, please read https://duck.co/duckduckhack/faq#how-do-i-install-a-missing-perl-dependency.\nNote: You can ignore these errors if you're not working on these instant answers.\n" if first { /dependencies/ } values %failed_to_load;
+    if (%$failed_to_load) {
+        $self->app->emit_notice("These instant answers were not loaded:");
+        $self->app->emit_notice(p($failed_to_load, colored => 1));
+        $self->app->emit_notice(
+            "To learn more about installing Perl dependencies, please read https://duck.co/duckduckhack/faq#how-do-i-install-a-missing-perl-dependency.",
+            "Note: You can ignore these errors if you're not working on these instant answers."
+        ) if first { /dependencies/ } values %$failed_to_load;
     }
 }
 
 sub get_blocks_from_current_dir {
-    my ( $self, @args ) = @_;
-    unless ($self->app->get_local_ddg_version) {
-        print "\n[ERROR] You need to have the DDG distribution installed\n";
-        print "\nTo get the installation command, please run: duckpan check\n\n";
-        exit 1;
-    }
-    my $type = $self->app->get_ia_type();
+    my ($self, @args) = @_;
+
+    $self->emit_and_exit(1, 'You need to have the DDG distribution installed', 'To get the installation command, please run: duckpan check')
+      unless ($self->app->get_local_ddg_version);
+
+    my $type   = $self->app->get_ia_type();
     my $finder = Module::Pluggable::Object->new(
         search_path => [$type->{dir}],
     );
@@ -51,26 +49,25 @@ sub get_blocks_from_current_dir {
         my @plugins = $finder->plugins;
         push @args, sort { $a cmp $b } @plugins;
         @args = map {
-                $_ =~ s!/!::!g;
-                my @parts = split('::',$_);
-                shift @parts;
-                join('::',@parts);
+            $_ =~ s!/!::!g;
+            my @parts = split('::', $_);
+            shift @parts;
+            join('::', @parts);
         } @args;
     } else {
-        @args = map { $_ = "DDG::". $type->{name} ."::$_" unless m,^lib(::|/)DDG,; $_; } @args;
+        @args = map { $_ = "DDG::" . $type->{name} . "::$_" unless m,^lib(::|/)DDG,; $_; } @args;
     }
     require lib;
     lib->import('lib');
-    print "\nUsing the following DDG instant answers:\n\n";
-    
-    
+    $self->app->emit_info("Loading Instant Answers...");
+
     # This list contains all of the classes that loaded successfully.
     my @successfully_loaded = ();
-    
+
     # This hash contains all of the modules that failed.
     # The key contains the module name and the value contains the dependency that wasn't met.
     my %failed_to_load = ();
-    
+
     # This loop goes through each Goodie / Spice, and it tries to load it.
     foreach my $class (@args) {
         # Let's try to load each Goodie / Spice module
@@ -79,19 +76,19 @@ sub get_blocks_from_current_dir {
 
         # If they load successfully, $load_success would be a 1.
         # Otherwise, it would be a 0.
-        if($load_success) {
-            # Since we only want the successful classes to trigger, we 
+        if ($load_success) {
+            # Since we only want the successful classes to trigger, we
             # collect all of the ones that triggered successfully in a temporary list.
             push @successfully_loaded, $class;
 
             # Display to the user when a class has been successfully loaded.
-            print " - $class (" . $class->triggers_block_type . ")\n";
+            $self->app->emit_debug(" - $class (" . $class->triggers_block_type . ")");
         } else {
             # Get the module name that needs to be installed by the user.
-            if($load_error_message =~ /Can't locate ([^\.]+).pm in \@INC/) {
+            if ($load_error_message =~ /Can't locate ([^\.]+).pm in \@INC/) {
                 $load_error_message = $1;
                 $load_error_message =~ s/\//::/g;
-                
+
                 $failed_to_load{$class} = "Please install $load_error_message and any other required dependencies to use this instant answer.";
             } else {
                 # We just set the value to whatever the error message was if it failed for some other reason.
@@ -105,8 +102,8 @@ sub get_blocks_from_current_dir {
     @args = @successfully_loaded;
 
     # Now let's tell the user why some of the modules failed.
-    print_failed_modules(\%failed_to_load);
-    
+    $self->show_failed_modules(\%failed_to_load);
+
     my %blocks_plugins;
     for (@args) {
         unless ($blocks_plugins{$_->triggers_block_type}) {
@@ -114,12 +111,16 @@ sub get_blocks_from_current_dir {
         }
         push @{$blocks_plugins{$_->triggers_block_type}}, $_;
     }
-    
+
     my @blocks;
     for (keys %blocks_plugins) {
-        my $block_class = 'DDG::Block::'.$_;
+        my $block_class = 'DDG::Block::' . $_;
         load_class($block_class);
-        push @blocks, $block_class->new( plugins => $blocks_plugins{$_}, return_one => 0 );
+        push @blocks,
+          $block_class->new(
+            plugins    => $blocks_plugins{$_},
+            return_one => 0
+          );
     }
     load_class('DDG::Request');
     return \@blocks;
@@ -137,7 +138,7 @@ App::DuckPAN::DDG - DDG related functionality of duckpan
 
 =head1 VERSION
 
-version 0.162
+version 0.163
 
 =head1 AUTHOR
 
